=== modified file 'Makefile'
--- Makefile	2008-05-05 23:40:13 +0000
+++ Makefile	2008-05-12 06:29:55 +0000
@@ -36,6 +36,8 @@
 
 check_launchpad_on_merge: build dbfreeze_check check importdcheck check_sourcecode_dependencies
 
+check_launchpad_storm_on_merge: build dbfreeze_check check_storm
+
 check_sourcecode_dependencies:
 	# Use the check_for_launchpad rule which runs tests over a smaller
 	# set of libraries, for performance and reliability reasons.
@@ -88,6 +90,12 @@
 	env PYTHONPATH=$(PYTHONPATH) \
 	${PYTHON} -t ./test_on_merge.py $(VERBOSITY)
 
+check_storm: build
+	# Run tests that should be clean on the Storm branch.  This will
+	# be ramped up to the entire test suite as we go.
+	env PYTHONPATH=$(PYTHONPATH) \
+	${PYTHON} -t ./test_on_merge.py $(VERBOSITY) -t /pagetests/
+
 lint:
 	@bash ./utilities/lint.sh
 
@@ -267,5 +275,6 @@
 		ftest_build ftest_inplace test_build test_inplace pagetests \
 		check importdcheck check_merge schema default launchpad.pot \
 		check_launchpad_on_merge check_merge_ui pull rewritemap scan \
-		sync_branches check_loggerhead_on_merge reload-apache
+		sync_branches check_loggerhead_on_merge reload-apache \
+		check_storm check_launchpad_storm_on_merge
 

=== modified file 'sourcecode/Makefile'
--- sourcecode/Makefile	2008-05-01 10:45:57 +0000
+++ sourcecode/Makefile	2008-05-12 06:29:55 +0000
@@ -5,9 +5,9 @@
 # (build and check targets work), or no makefile we can reenable auto
 # detection.
 # test_dirs:=$(shell find . -maxdepth 1 -mindepth 1 -name ".arch-ids" -prune -o -type d -print | grep -v pyarch)
-build_dirs:=buildbot bzr cscvs pygettextpo pygpgme sqlobject twisted zope
-test_dirs:=buildbot bzr cscvs pygettextpo sqlobject storm twisted zope
-launchpad_test_dirs:=buildbot pygettextpo sqlobject zope
+build_dirs:=buildbot bzr cscvs pygettextpo pygpgme storm twisted zope
+test_dirs:=buildbot bzr cscvs pygettextpo storm twisted zope
+launchpad_test_dirs:=buildbot pygettextpo storm zope
 
 all:
 

=== modified file 'test_on_merge.py'
--- test_on_merge.py	2007-05-01 21:05:02 +0000
+++ test_on_merge.py	2008-05-12 06:29:55 +0000
@@ -7,7 +7,7 @@
 import os, os.path, errno
 import tabnanny
 from StringIO import StringIO
-import psycopg
+import psycopg2
 from subprocess import Popen, PIPE, STDOUT
 from signal import SIGKILL, SIGTERM
 from select import select
@@ -44,7 +44,7 @@
 
     # Sanity check PostgreSQL version. No point in trying to create a test
     # database when PostgreSQL is too old.
-    con = psycopg.connect('dbname=template1')
+    con = psycopg2.connect('dbname=template1')
     cur = con.cursor()
     cur.execute('show server_version')
     server_version = cur.fetchone()[0]
@@ -62,12 +62,12 @@
 
     # Drop the template database if it exists - the Makefile does this
     # too, but we can explicity check for errors here
-    con = psycopg.connect('dbname=template1')
+    con = psycopg2.connect('dbname=template1')
     con.set_isolation_level(0)
     cur = con.cursor()
     try:
         cur.execute('drop database launchpad_ftest_template')
-    except psycopg.ProgrammingError, x:
+    except psycopg2.ProgrammingError, x:
         if 'does not exist' not in str(x):
             raise
     cur.execute("""
@@ -95,7 +95,7 @@
 
     # Sanity check the database. No point running tests if the
     # bedrock is crumbling.
-    con = psycopg.connect('dbname=launchpad_ftest_template')
+    con = psycopg2.connect('dbname=launchpad_ftest_template')
     cur = con.cursor()
     cur.execute('show search_path')
     search_path = cur.fetchone()[0]

=== modified file 'utilities/check-sampledata.py'
--- utilities/check-sampledata.py	2007-03-14 21:20:20 +0000
+++ utilities/check-sampledata.py	2008-05-12 06:29:55 +0000
@@ -26,7 +26,7 @@
 import re
 from textwrap import dedent
 
-from psycopg import ProgrammingError
+from psycopg2 import ProgrammingError
 
 from zope.interface import providedBy
 from zope.interface.exceptions import (

=== modified file 'utilities/pgcreate.py'
--- utilities/pgcreate.py	2007-10-08 10:35:22 +0000
+++ utilities/pgcreate.py	2008-05-12 06:29:55 +0000
@@ -10,7 +10,7 @@
 
 import sys
 import time
-import psycopg
+import psycopg2
 
 def main():
     if len(sys.argv) != 3:
@@ -20,7 +20,7 @@
     template, dbname = sys.argv[1:]
 
     for attempt in range(0, 10):
-        con = psycopg.connect('dbname=template1')
+        con = psycopg2.connect('dbname=template1')
         con.set_isolation_level(0)
         try:
             cur = con.cursor()
@@ -29,7 +29,7 @@
                         dbname, template
                         )
                     )
-        except psycopg.Error:
+        except psycopg2.Error:
             if attempt == 9:
                 raise
             con.close()

=== modified file 'utilities/pgkillidle.py'
--- utilities/pgkillidle.py	2007-03-14 21:20:20 +0000
+++ utilities/pgkillidle.py	2008-05-12 06:29:55 +0000
@@ -10,7 +10,7 @@
 
 from optparse import OptionParser
 import os
-import psycopg
+import psycopg2
 import signal
 import sys
 
@@ -38,7 +38,7 @@
     if len(args) > 0:
         parser.error('Too many arguments')
 
-    con = psycopg.connect(options.connect_string)
+    con = psycopg2.connect(options.connect_string)
     cur = con.cursor()
     cur.execute("""
         SELECT procpid, backend_start, query_start

=== modified file 'utilities/pgmassacre.py'
--- utilities/pgmassacre.py	2008-01-29 11:18:39 +0000
+++ utilities/pgmassacre.py	2008-05-12 06:29:55 +0000
@@ -7,7 +7,8 @@
 
 import sys
 import time
-import psycopg
+import psycopg2
+import psycopg2.extensions
 from signal import SIGTERM, SIGQUIT, SIGKILL, SIGINT
 from optparse import OptionParser
 
@@ -15,9 +16,9 @@
 def connect(dbname='template1'):
     """Connect to the database, returning the DB-API connection."""
     if options.user is not None:
-        return psycopg.connect("dbname=%s user=%s" % (dbname, options.user))
+        return psycopg2.connect("dbname=%s user=%s" % (dbname, options.user))
     else:
-        return psycopg.connect("dbname=%s" % dbname)
+        return psycopg2.connect("dbname=%s" % dbname)
 
 
 def send_signal(database, signal):
@@ -31,7 +32,7 @@
         cur.execute('CREATE LANGUAGE "plpythonu"')
 
     # Create a stored procedure to kill a backend process.
-    qdatabase = str(psycopg.QuotedString(database))
+    qdatabase = str(psycopg2.extensions.QuotedString(database))
     cur.execute("""
         CREATE OR REPLACE FUNCTION _pgmassacre_killall(integer)
         RETURNS Boolean AS $$

=== modified file 'utilities/pgstats.py'
--- utilities/pgstats.py	2007-08-04 15:40:41 +0000
+++ utilities/pgstats.py	2008-05-12 06:29:55 +0000
@@ -8,7 +8,7 @@
 __metaclass__ = type
 
 import sys
-import psycopg
+import psycopg2
 
 def percentage(num, total):
     """Return a percentage string of num/total"""
@@ -48,7 +48,7 @@
 
 
 def main(dbname):
-    con = psycopg.connect("dbname=%s" % dbname)
+    con = psycopg2.connect("dbname=%s" % dbname)
     cur = con.cursor()
 
     print 'Statistics for %s' % dbname

